@@ -7,8 +7,7 @@ import json
 from typing import Optional, List
 
 # Internal imports
-from fastfuels_sdk.api import get_client
-from fastfuels_sdk.client_library.api import DomainsApi
+from fastfuels_sdk.api import get_domains_api
 from fastfuels_sdk.client_library.models import (
     Domain as DomainModel,
     CreateDomainRequest,
@@ -21,8 +20,6 @@ from fastfuels_sdk.client_library.models import (
 # External imports
 import geopandas as gpd
 
-_DOMAIN_API = DomainsApi(get_client())
-
 
 class Domain(DomainModel):
     """Domain resource for the FastFuels API.
@@ -110,7 +107,7 @@ class Domain(DomainModel):
         >>> domain.id
         'abc123'
         """
-        get_domain_response = _DOMAIN_API.get_domain(domain_id)
+        get_domain_response = get_domains_api().get_domain(domain_id)
         return cls(**get_domain_response.model_dump())
 
     @classmethod
@@ -178,7 +175,7 @@ class Domain(DomainModel):
         }
 
         request = CreateDomainRequest.from_dict(feature_data)
-        response = _DOMAIN_API.create_domain(
+        response = get_domains_api().create_domain(
             create_domain_request=request.model_dump()  # noqa
         )
         return cls(**response.model_dump()) if response else None
@@ -297,7 +294,7 @@ class Domain(DomainModel):
         ensure all references to this Domain instance see the updated data.
         """
         # Fetch latest data from API
-        response = _DOMAIN_API.get_domain(self.id)
+        response = get_domains_api().get_domain(self.id)
 
         if in_place:
             # Update all attributes of current instance
@@ -371,7 +368,7 @@ class Domain(DomainModel):
         # Only make API call if there are fields to update
         if update_data:
             request = UpdateDomainRequest(**update_data)
-            response = _DOMAIN_API.update_domain(
+            response = get_domains_api().update_domain(
                 domain_id=self.id, update_domain_request=request
             )
 
@@ -467,6 +464,45 @@ class Domain(DomainModel):
 
         return gdf
 
+    def export(self) -> dict:
+        """Export all domain metadata including features, grids, and inventories.
+
+        Returns domain configuration and metadata for all resources without including
+        large data payloads like grid arrays, GeoJSON features, or tree records.
+
+        Returns
+        -------
+        dict
+            Dictionary containing:
+            - domain: Full domain metadata (id, name, description, resolutions, CRS, etc.)
+            - features: Feature metadata excluding GeoJSON data
+            - grids: Grid metadata excluding array data
+            - inventories: Inventory metadata excluding tree records
+
+        Examples
+        --------
+        Export domain metadata:
+        >>> domain = Domain.from_id("abc123")
+        >>> export_data = domain.export()
+        >>> print(export_data['domain']['name'])
+        'My Domain'
+        >>> print(export_data['grids']['tree']['status'])
+        'completed'
+
+        Save export to file:
+        >>> export_data = domain.export()
+        >>> with open('domain_export.json', 'w') as f:
+        ...     json.dump(export_data, f, indent=2)
+
+        Notes
+        -----
+        Large data payloads are excluded to keep response size manageable:
+        - Feature GeoJSON: Use dedicated feature export endpoints
+        - Grid array data: Use grid export endpoints
+        - Tree inventory records: Use inventory export endpoints
+        """
+        return get_domains_api().export_domain_data(domain_id=self.id)
+
     def delete(self) -> None:
         """Delete an existing domain resource based on the domain ID.
 
@@ -487,7 +523,7 @@ class Domain(DomainModel):
         >>> domain.get()
         # Raises NotFoundException
         """
-        _DOMAIN_API.delete_domain(domain_id=self.id)
+        get_domains_api().delete_domain(domain_id=self.id)
         return None
 
 
@@ -550,7 +586,7 @@ def list_domains(
     """
     sort_by = DomainSortField(sort_by) if sort_by else None
     sort_order = DomainSortOrder(sort_order) if sort_order else None
-    list_response = _DOMAIN_API.list_domains(
+    list_response = get_domains_api().list_domains(
         page=page, size=size, sort_by=sort_by, sort_order=sort_order
     )
     list_response.domains = [Domain(**d.model_dump()) for d in list_response.domains]
