@@ -9,10 +9,12 @@ from pathlib import Path
 from typing import Optional
 
 # Internal imports
-from fastfuels_sdk.api import get_client
-from fastfuels_sdk.utils import parse_dict_items_to_pydantic_list
+from fastfuels_sdk.api import get_inventories_api, get_tree_inventory_api
+from fastfuels_sdk.utils import (
+    parse_dict_items_to_pydantic_list,
+    format_processing_error,
+)
 from fastfuels_sdk.exports import Export
-from fastfuels_sdk.client_library.api import InventoriesApi, TreeInventoryApi
 from fastfuels_sdk.client_library.models import (
     Inventories as InventoriesModel,
     TreeInventory as TreeInventoryModel,
@@ -28,9 +30,6 @@ from fastfuels_sdk.client_library.models import (
 # External imports
 import requests
 
-_INVENTORIES_API = InventoriesApi(get_client())
-_TREE_INVENTORY_API = TreeInventoryApi(get_client())
-
 
 class Inventories(InventoriesModel):
     """
@@ -73,7 +72,9 @@ class Inventories(InventoriesModel):
         >>> from fastfuels_sdk import Inventories
         >>> inventories = Inventories.from_domain_id("abc123")
         """
-        inventories_response = _INVENTORIES_API.get_inventories(domain_id=domain_id)
+        inventories_response = get_inventories_api().get_inventories(
+            domain_id=domain_id
+        )
         response_data = inventories_response.model_dump()
         response_data = _convert_api_models_to_sdk_classes(domain_id, response_data)
 
@@ -107,7 +108,7 @@ class Inventories(InventoriesModel):
         >>> # Fetch and update the inventory data in place
         >>> inventories.get(in_place=True)
         """
-        response = _INVENTORIES_API.get_inventories(domain_id=self.domain_id)
+        response = get_inventories_api().get_inventories(domain_id=self.domain_id)
         response_data = response.model_dump()
         response_data = _convert_api_models_to_sdk_classes(
             self.domain_id, response_data
@@ -148,18 +149,67 @@ class Inventories(InventoriesModel):
             - seed: Integer for reproducible generation (optional)
 
         modifications : dict or list[dict], optional
-            List of modifications to apply. Each modification has:
-            - conditions: List of conditions that must be met
-            - actions: List of actions to apply when conditions are met
+            Rules for modifying or removing tree attributes. Each modification has:
+            - conditions: List of conditions that trees must meet
+            - actions: List of actions to apply to matching trees
 
-            Example:
+            Conditions can be:
+            1. Simple field conditions: Compare a single field to a value
+            2. Expression-based conditions: Use arithmetic expressions combining multiple fields
+
+            Example - Modify attribute:
             ```python
             {
-                "conditions": [{"field": "HT", "operator": "gt", "value": 20}],
-                "actions": [{"field": "HT", "modifier": "multiply", "value": 0.9}]
+                "conditions": [{"attribute": "HT", "operator": "gt", "value": 20}],
+                "actions": [{"attribute": "HT", "modifier": "multiply", "value": 0.9}]
             }
             ```
 
+            Example - Remove all trees with a diameter (DIA) less than 10cm:
+            ```python
+            {
+                "conditions": [{"attribute": "DIA", "operator": "lt", "value": 10}],
+                "actions": [{"modifier": "remove"}]
+            }
+            ```
+
+            Example - Expression-based condition (remove trees with crown length < 1m):
+            ```python
+            {
+                "conditions": [{
+                    "attribute": "expression",
+                    "expression": "HT * CR",  # Crown length calculation
+                    "operator": "lt",
+                    "value": 1.0
+                }],
+                "actions": [{"modifier": "remove"}]
+            }
+            ```
+
+            Example - Multiple conditions (remove tall, slender Douglas-fir):
+            ```python
+            {
+                "conditions": [
+                    {"attribute": "SPCD", "operator": "eq", "value": 202},
+                    {"attribute": "expression", "expression": "HT / DIA", "operator": "gt", "value": 100}
+                ],
+                "actions": [{"modifier": "remove"}]
+            }
+            ```
+
+            Available field attributes: HT (height), DIA (diameter), CR (crown ratio), SPCD (species code)
+            Available operators: eq, ne, gt, lt, ge, le
+            Available modifiers: multiply, divide, add, subtract, replace, remove
+
+            Expression syntax:
+            - Fields: HT, DIA, CR
+            - Operators: +, -, *, /, ()
+            - Example expressions: "HT * CR", "HT / DIA", "(HT + DIA) / 2", "HT * (1 - CR)"
+            - Common patterns:
+              * Crown length: HT * CR
+              * Crown base height: HT * (1 - CR)
+              * Slenderness ratio: HT / DIA
+
         treatments : dict or list[dict], optional
             List of silvicultural treatments to apply. Supports:
 
@@ -220,8 +270,17 @@ class Inventories(InventoriesModel):
         >>> inventory = inventories.create_tree_inventory(
         ...     sources="TreeMap",
         ...     modifications={
-        ...         "conditions": [{"field": "HT", "operator": "gt", "value": 20}],
-        ...         "actions": [{"field": "HT", "modifier": "multiply", "value": 0.9}]
+        ...         "conditions": [{"attribute": "HT", "operator": "gt", "value": 20}],
+        ...         "actions": [{"attribute": "HT", "modifier": "multiply", "value": 0.9}]
+        ...     }
+        ... )
+
+        Remove small trees:
+        >>> inventory = inventories.create_tree_inventory(
+        ...     sources="TreeMap",
+        ...     modifications={
+        ...         "conditions": [{"attribute": "DIA", "operator": "lt", "value": 10}],
+        ...         "actions": [{"attribute": "all", "modifier": "remove"}]
         ...     }
         ... )
 
@@ -254,11 +313,13 @@ class Inventories(InventoriesModel):
                 [feature_masks] if isinstance(feature_masks, str) else feature_masks
             ),
         )
-        response = _TREE_INVENTORY_API.create_tree_inventory(
+        response = get_tree_inventory_api().create_tree_inventory(
             self.domain_id, request_body
         )
+        # Copy attributes directly from response to avoid re-serialization
         tree_inventory = TreeInventory(
-            domain_id=self.domain_id, **response.model_dump()
+            domain_id=self.domain_id,
+            **{field: getattr(response, field) for field in response.model_fields},
         )
         if in_place:
             self.tree = tree_inventory
@@ -314,24 +375,67 @@ class Inventories(InventoriesModel):
             - "Meta2024": Meta's 2024 global canopy height map at 1-meter resolution
 
         modifications : dict or list[dict], optional
-            Rules for modifying tree attributes. Each modification includes:
-            - conditions: List of criteria that trees must meet
+            Rules for modifying or removing tree attributes. Each modification includes:
+            - conditions: List of criteria that trees must meet (all must be true - AND logic)
             - actions: Changes to apply to matching trees
 
-            Example - Reduce height of tall trees:
+            Conditions support both simple field comparisons and arithmetic expressions
+            combining multiple fields.
+
+            Example - Modify attribute:
             ```python
             {
-                "conditions": [{"field": "HT", "operator": "gt", "value": 20}],
-                "actions": [{"field": "HT", "modifier": "multiply", "value": 0.9}]
+                "conditions": [{"attribute": "HT", "operator": "gt", "value": 20}],
+                "actions": [{"attribute": "HT", "modifier": "multiply", "value": 0.9}]
             }
             ```
 
-            Available fields:
+            Example - Remove trees (simplified syntax):
+            ```python
+            {
+                "conditions": [{"attribute": "DIA", "operator": "lt", "value": 10}],
+                "actions": [{"modifier": "remove"}]
+            }
+            ```
+
+            Example - Expression-based (remove trees with short crowns):
+            ```python
+            {
+                "conditions": [{
+                    "attribute": "expression",
+                    "expression": "HT * CR",  # Crown length
+                    "operator": "lt",
+                    "value": 1.0
+                }],
+                "actions": [{"modifier": "remove"}]
+            }
+            ```
+
+            Example - Multiple conditions (remove unrealistic slender trees):
+            ```python
+            {
+                "conditions": [
+                    {"attribute": "expression", "expression": "HT / DIA", "operator": "gt", "value": 100},
+                    {"attribute": "HT", "operator": "gt", "value": 5}
+                ],
+                "actions": [{"modifier": "remove"}]
+            }
+            ```
+
+            Available field attributes:
             - HT: Height (meters)
             - DIA: Diameter at breast height (centimeters)
             - CR: Crown ratio (0-1)
             - SPCD: Species code (integer)
 
+            Available operators: eq, ne, gt, lt, ge, le
+            Available modifiers: multiply, divide, add, subtract, replace, remove
+
+            Expression syntax (for expression-based conditions):
+            - Fields: HT, DIA, CR
+            - Operators: +, -, *, /, ()
+            - Common patterns: "HT * CR" (crown length), "HT / DIA" (slenderness), "HT * (1 - CR)" (crown base height)
+
         treatments : dict or list[dict], optional
             Silvicultural treatments to apply. Supports:
 
@@ -395,8 +499,16 @@ class Inventories(InventoriesModel):
         Reduce height of tall trees:
         >>> tree_inventory = inventories.create_tree_inventory_from_treemap(
         ...     modifications={
-        ...         "conditions": [{"field": "HT", "operator": "gt", "value": 20}],
-        ...         "actions": [{"field": "HT", "modifier": "multiply", "value": 0.9}]
+        ...         "conditions": [{"attribute": "HT", "operator": "gt", "value": 20}],
+        ...         "actions": [{"attribute": "HT", "modifier": "multiply", "value": 0.9}]
+        ...     }
+        ... )
+
+        Remove small trees:
+        >>> tree_inventory = inventories.create_tree_inventory_from_treemap(
+        ...     modifications={
+        ...         "conditions": [{"attribute": "DIA", "operator": "lt", "value": 10}],
+        ...         "actions": [{"attribute": "all", "modifier": "remove"}]
         ...     }
         ... )
 
@@ -418,8 +530,8 @@ class Inventories(InventoriesModel):
         >>> tree_inventory = inventories.create_tree_inventory_from_treemap(
         ...     seed=42,
         ...     modifications={
-        ...         "conditions": [{"field": "HT", "operator": "gt", "value": 20}],
-        ...         "actions": [{"field": "HT", "modifier": "multiply", "value": 0.9}]
+        ...         "conditions": [{"attribute": "HT", "operator": "gt", "value": 20}],
+        ...         "actions": [{"attribute": "HT", "modifier": "multiply", "value": 0.9}]
         ...     },
         ...     treatments={
         ...         "method": "proportionalThinning",
@@ -534,7 +646,7 @@ class Inventories(InventoriesModel):
             raise ValueError(f"File must be a CSV: {file_path}")
 
         # Create tree inventory resource with "file" source
-        signed_url_response = _TREE_INVENTORY_API.create_tree_inventory(
+        signed_url_response = get_tree_inventory_api().create_tree_inventory(
             self.domain_id,
             CreateTreeInventoryRequest(sources=[TreeInventorySource.FILE]),
         )
@@ -549,8 +661,13 @@ class Inventories(InventoriesModel):
             if upload_response.status_code != 200:
                 raise ValueError(f"Failed to upload file: {upload_response.text}")
 
+        # Copy attributes directly from response to avoid re-serialization
         tree_inventory = TreeInventory(
-            domain_id=self.domain_id, **signed_url_response.model_dump()
+            domain_id=self.domain_id,
+            **{
+                field: getattr(signed_url_response, field)
+                for field in signed_url_response.model_fields
+            },
         )
 
         return tree_inventory
@@ -668,8 +785,12 @@ class TreeInventory(TreeInventoryModel):
         - Use get() to refresh the inventory data and wait_until_completed() to wait
           for processing to finish
         """
-        response = _TREE_INVENTORY_API.get_tree_inventory(domain_id=domain_id)
-        return cls(domain_id=domain_id, **response.model_dump())
+        response = get_tree_inventory_api().get_tree_inventory(domain_id=domain_id)
+        # Copy attributes directly from response to avoid re-serialization
+        return cls(
+            domain_id=domain_id,
+            **{field: getattr(response, field) for field in response.model_fields},
+        )
 
     def get(self, in_place: bool = False):
         """
@@ -733,13 +854,17 @@ class TreeInventory(TreeInventoryModel):
         - This method is often used in conjunction with wait_until_completed()
           to monitor the progress of tree inventory processing.
         """
-        response = _TREE_INVENTORY_API.get_tree_inventory(domain_id=self.domain_id)
+        response = get_tree_inventory_api().get_tree_inventory(domain_id=self.domain_id)
         if in_place:
-            # Update all attributes of current instance
-            for key, value in response.model_dump().items():
-                setattr(self, key, value)
+            # Update all attributes of current instance from response
+            for field in response.model_fields:
+                setattr(self, field, getattr(response, field))
             return self
-        return TreeInventory(domain_id=self.domain_id, **response.model_dump())
+        # Copy attributes directly from response to avoid re-serialization
+        return TreeInventory(
+            domain_id=self.domain_id,
+            **{field: getattr(response, field) for field in response.model_fields},
+        )
 
     def wait_until_completed(
         self,
@@ -832,7 +957,16 @@ class TreeInventory(TreeInventoryModel):
         tree_inventory = self.get(in_place=in_place if in_place else False)
         while tree_inventory.status != "completed":
             if tree_inventory.status == "failed":
-                raise RuntimeError("Tree inventory processing failed.")
+                error_msg = "Tree inventory processing failed."
+
+                # Extract detailed error information if available
+                error_obj = getattr(tree_inventory, "error", None)
+                if error_obj:
+                    error_details = format_processing_error(error_obj)
+                    if error_details:
+                        error_msg = f"{error_msg}\n\n{error_details}"
+
+                raise RuntimeError(error_msg)
             if elapsed_time >= timeout:
                 raise TimeoutError("Timed out waiting for tree inventory to finish.")
             sleep(step)
@@ -882,7 +1016,7 @@ class TreeInventory(TreeInventoryModel):
         - Consider creating an export of important inventory data before deletion
           using create_export()
         """
-        _TREE_INVENTORY_API.delete_tree_inventory(domain_id=self.domain_id)
+        get_tree_inventory_api().delete_tree_inventory(domain_id=self.domain_id)
 
         return None
 
@@ -963,7 +1097,7 @@ class TreeInventory(TreeInventoryModel):
           process - use get() to check status, wait_until_completed() to wait for
           completion, and to_file() to download
         """
-        response = _TREE_INVENTORY_API.create_tree_inventory_export(
+        response = get_tree_inventory_api().create_tree_inventory_export(
             domain_id=self.domain_id, export_format=export_format
         )
         return Export(**response.model_dump())
@@ -1027,7 +1161,7 @@ class TreeInventory(TreeInventoryModel):
           create_export().wait_until_completed() is simpler
         - Always check the export's status before attempting to download using to_file()
         """
-        response = _TREE_INVENTORY_API.get_tree_inventory_export(
+        response = get_tree_inventory_api().get_tree_inventory_export(
             domain_id=self.domain_id, export_format=export_format
         )
         return Export(**response.model_dump())
