@@ -199,14 +199,29 @@ class TestCreateTreeInventory:
                 assert condition["attribute"] == mod_condition["attribute"]
                 assert condition["operator"] == mod_condition["operator"]
                 assert condition["value"] == mod_condition["value"]
+                # Check expression field if present
+                if "expression" in condition:
+                    assert condition["expression"] == mod_condition["expression"]
 
             for action, mod_action in zip(modification["actions"], mod["actions"]):
-                assert action["attribute"] == mod_action["attribute"]
-                assert action["modifier"] == mod_action["modifier"]
-                if action["modifier"] != "remove":
-                    assert action["value"] == mod_action["value"]
-                else:
+                # Handle both old and new remove syntax
+                if action["modifier"] == "remove":
+                    assert action["modifier"] == mod_action["modifier"]
+                    # attribute field is optional for remove actions
+                    # API normalizes "all" to None
+                    if "attribute" in action:
+                        expected_attr = action["attribute"]
+                        actual_attr = mod_action.get("attribute")
+                        # Accept either "all" or None for remove actions
+                        if expected_attr == "all":
+                            assert actual_attr in ["all", None]
+                        else:
+                            assert expected_attr == actual_attr
                     assert "value" not in mod_action
+                else:
+                    assert action["attribute"] == mod_action["attribute"]
+                    assert action["modifier"] == mod_action["modifier"]
+                    assert action["value"] == mod_action["value"]
 
     def test_modifications_single(self, test_inventories):
         """Tests single modification"""
@@ -246,6 +261,88 @@ class TestCreateTreeInventory:
         assert len(tree_inventory.modifications) == 2
         self.validate_modifications(tree_inventory, modifications)
 
+    def test_modifications_expression_crown_length(self, test_inventories):
+        """Tests expression-based condition for crown length filtering"""
+        modification = {
+            "conditions": [
+                {
+                    "attribute": "expression",
+                    "expression": "HT * CR",
+                    "operator": "lt",
+                    "value": 1.0,
+                }
+            ],
+            "actions": [{"modifier": "remove"}],
+        }
+
+        tree_inventory = test_inventories.create_tree_inventory(
+            sources="TreeMap", modifications=modification
+        )
+
+        self.assert_data_validity(tree_inventory, test_inventories.domain_id)
+        assert len(tree_inventory.modifications) == 1
+        self.validate_modifications(tree_inventory, [modification])
+
+    def test_modifications_expression_slenderness_ratio(self, test_inventories):
+        """Tests expression-based condition for slenderness ratio"""
+        modification = {
+            "conditions": [
+                {
+                    "attribute": "expression",
+                    "expression": "HT / DIA",
+                    "operator": "gt",
+                    "value": 100.0,
+                }
+            ],
+            "actions": [{"modifier": "remove"}],
+        }
+
+        tree_inventory = test_inventories.create_tree_inventory(
+            sources="TreeMap", modifications=modification
+        )
+
+        self.assert_data_validity(tree_inventory, test_inventories.domain_id)
+        assert len(tree_inventory.modifications) == 1
+        self.validate_modifications(tree_inventory, [modification])
+
+    def test_modifications_expression_with_field_condition(self, test_inventories):
+        """Tests expression condition combined with field condition"""
+        modification = {
+            "conditions": [
+                {"attribute": "SPCD", "operator": "eq", "value": 202},
+                {
+                    "attribute": "expression",
+                    "expression": "HT / DIA",
+                    "operator": "gt",
+                    "value": 100.0,
+                },
+            ],
+            "actions": [{"modifier": "remove"}],
+        }
+
+        tree_inventory = test_inventories.create_tree_inventory(
+            sources="TreeMap", modifications=modification
+        )
+
+        self.assert_data_validity(tree_inventory, test_inventories.domain_id)
+        assert len(tree_inventory.modifications) == 1
+        self.validate_modifications(tree_inventory, [modification])
+
+    def test_modifications_simplified_remove_syntax(self, test_inventories):
+        """Tests simplified remove action syntax without attribute field"""
+        modification = {
+            "conditions": [{"attribute": "DIA", "operator": "lt", "value": 10}],
+            "actions": [{"modifier": "remove"}],
+        }
+
+        tree_inventory = test_inventories.create_tree_inventory(
+            sources="TreeMap", modifications=modification
+        )
+
+        self.assert_data_validity(tree_inventory, test_inventories.domain_id)
+        assert len(tree_inventory.modifications) == 1
+        self.validate_modifications(tree_inventory, [modification])
+
     def test_treatments_single(self, test_inventories):
         """Tests single treatment"""
         treatment = {
@@ -515,6 +612,21 @@ class TestCreateTreeInventoryFromFileUpload:
         }
         return pd.DataFrame(data)
 
+    @pytest.fixture
+    def invalid_tree_data_large_cr(self):
+        num_trees = int(1e4)
+        data = {
+            "TREE_ID": np.arange(num_trees, dtype=np.int64),
+            "SPCD": np.random.randint(1, 100, num_trees),
+            "STATUSCD": np.random.randint(0, 4, num_trees),
+            "DIA": np.random.uniform(0, 1200, num_trees),
+            "HT": np.random.uniform(0, 116, num_trees),
+            "CR": np.random.uniform(0, 100, num_trees),
+            "X": np.random.uniform(721064.0, 721514.0, num_trees),
+            "Y": np.random.uniform(5190012.0, 5190284.0, num_trees),
+        }
+        return pd.DataFrame(data)
+
     @pytest.fixture
     def temp_csv_file(self, valid_tree_data):
         """Fixture to create a temporary CSV file with valid data"""
@@ -551,6 +663,22 @@ class TestCreateTreeInventoryFromFileUpload:
         with pytest.raises(ValueError, match="File must be a CSV"):
             test_inventories.create_tree_inventory_from_file_upload(invalid_file)
 
+    def test_invalid_data_large_cr(self, test_inventories, invalid_tree_data_large_cr):
+        """Test handling of CSV with invalid CR values (>1) - verifies detailed error reporting"""
+        with tempfile.NamedTemporaryFile(delete=False, suffix=".csv") as tmp:
+            invalid_tree_data_large_cr.to_csv(tmp.name, index=False)
+
+            data = test_inventories.create_tree_inventory_from_file_upload(tmp.name)
+
+            # Verify that wait_until_completed raises RuntimeError with detailed error info
+            with pytest.raises(RuntimeError) as exc_info:
+                data.wait_until_completed()
+
+            error_msg = str(exc_info.value)
+            assert "Tree inventory processing failed" in error_msg
+            assert "SCHEMA_VALIDATION_ERROR" in error_msg
+            assert "Crown ratio must be between 0 and 1" in error_msg
+
     # TODO: Consider adding local checks to create_tree_inventory_from_file_upload for this. Otherwise, we will rely on API tests
     # def test_file_too_large(self, test_inventories, valid_tree_data):
     #     """Test handling of file exceeding size limit"""
